@@ -10,6 +10,16 @@ pub use idx_vec::{Enumerated, IndexVec, IntoIdx};
 #[cfg(feature = "serde")]
 pub use serde::{Deserialize, Serialize};
 
+#[cfg(feature = "serde")]
+fn _is_serde<T: Serialize + serde::de::DeserializeOwned>(_: &T) {
+}
+
+#[cfg(feature = "serde")]
+fn _idx_is_serde() {
+    newtype_index!(Foo);
+    _is_serde(&Foo::new(0));
+}
+
 #[macro_export]
 macro_rules! newtype_index {
     (
